@@ -1,4 +1,10 @@
 package DBD::Oracle::GetInfo;
+{
+  $DBD::Oracle::GetInfo::VERSION = '1.38';
+}
+BEGIN {
+  $DBD::Oracle::GetInfo::AUTHORITY = 'cpan:PYTHIAN';
+}
 
 use strict;
 use DBD::Oracle();
@@ -314,4 +320,44 @@ our %info = (
 
 1;
 
+
+
+=pod
+
+=head1 NAME
+
+DBD::Oracle::GetInfo
+
+=head1 VERSION
+
+version 1.38
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Tim Bunce <timb@cpan.org>
+
+=item *
+
+John Scoles
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 1994 by Tim Bunce.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
 __END__
