@@ -1,9 +1,24 @@
+package DBD::Oracle::Troubleshooting;
+{
+  $DBD::Oracle::Troubleshooting::VERSION = '1.38';
+}
+BEGIN {
+  $DBD::Oracle::Troubleshooting::AUTHORITY = 'cpan:PYTHIAN';
+}
+#ABSTRACT: Tips and Hints to Troubleshoot DBD::Oracle
+
+
+__END__
 =pod
 
 =head1 NAME
 
 DBD::Oracle::Troubleshooting - Tips and Hints to Troubleshoot DBD::Oracle
 
+=head1 VERSION
+
+version 1.38
+
 =head1 CONNECTING TO ORACLE
 
 If you are reading this it is assumed that you have successfully
@@ -30,7 +45,6 @@ For Windows the solution is to add this value to you PATH
 
   PATH=c:\app\oracle\product\xx.x.x;%PATH%
 
-
 If you get past this stage and get a
 
   ORA-12154: TNS:could not resolve the connect identifier specified
@@ -62,7 +76,6 @@ Protocol Adapter".
 If it generates any errors which look relevant then please talk to your
 Oracle technical support (and not the dbi-users mailing list).
 
-
 =head1 USING THE LONG TYPES
 
 Some examples related to the use of LONG types are available in
@@ -97,7 +110,6 @@ It turns out that now it is necessary to edit the same file and append
 this and then run "genclntsh", the libclntsh is properly generated and
 the linkage with DBD::Oracle proceeds properly.
 
-
 =head2 cc1: invalid option `tune=pentium4'" error
 
 If you get the above it seems that eiter your Perl or OS where compiled with a different version of GCC or the GCC that is on your system is very old.
@@ -154,7 +166,7 @@ To get 10Xe to compile correctly I had to add $ORACLE_HOME/lib to the LD_LIBRARY
 as you would for an install against 10g Standard Edition, Standard Edition One, or 
 Enterprise Edition 
 
-=head2  UTF8 bug in Oracle  9.2.0.5.0 and 9.2.0.7.0
+=head2 UTF8 bug in Oracle  9.2.0.5.0 and 9.2.0.7.0
 
 DBD::Oracle seems to hit some sort of bug with the above two versions of DB.
 The bug seems to hit when you when the Oracle database charset: US7ASCII and the Oracle nchar charset: AL16UTF16 and it has also
@@ -173,7 +185,6 @@ So far there is no patch for this but here are some work arounds
     or this way
 
     utf8::downgrade($parameter, 1);
-	
 
 =head1 CYGWIN
 
@@ -336,4 +347,30 @@ oracle table implementation, and no UTF support.
 Oracle 9.0 is uncertain, since testing has not been possible yet,
 but the remedy will not hurt :)
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Tim Bunce <timb@cpan.org>
+
+=item *
+
+John Scoles
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 1994 by Tim Bunce.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
